aboutsummaryrefslogtreecommitdiff
path: root/scumm/scummvm.cpp
diff options
context:
space:
mode:
authorMarcus Comstedt2003-05-04 13:59:08 +0000
committerMarcus Comstedt2003-05-04 13:59:08 +0000
commitb98ed367b03cd281530a8836c785ac612c19e84b (patch)
treeab6d792b16dea45cd57cde27f014d50fe60294b5 /scumm/scummvm.cpp
parent3f51ed8ff0edac4e8778163d3bcd9de6437e0676 (diff)
downloadscummvm-rg350-b98ed367b03cd281530a8836c785ac612c19e84b.tar.gz
scummvm-rg350-b98ed367b03cd281530a8836c785ac612c19e84b.tar.bz2
scummvm-rg350-b98ed367b03cd281530a8836c785ac612c19e84b.zip
Even more heap needed by later games...
svn-id: r7320
Diffstat (limited to 'scumm/scummvm.cpp')
-rw-r--r--scumm/scummvm.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/scumm/scummvm.cpp b/scumm/scummvm.cpp
index f77f41e0b7..234a827064 100644
--- a/scumm/scummvm.cpp
+++ b/scumm/scummvm.cpp
@@ -2038,14 +2038,14 @@ void Scumm::launch() {
#ifdef __PALM_OS__
// PALMOS : check if this value is correct with palm,
// old value 450000 doesn't work anymore (return _fntPtr = NULL in zak256, not tested with others)
// 1500000 is too big and make ScummVM crashes : MemMove to NULL or immediate exit if try to allocate
// memory with new operator
_maxHeapThreshold = 550000;
#else
// Since the new costumes are very big, we increase the heap limit, to avoid having
// to constantly reload stuff from the data files.
if (_features & GF_NEW_COSTUMES)
- _maxHeapThreshold = 1500000;
+ _maxHeapThreshold = 2500000;
else
_maxHeapThreshold = 550000;
#endif
@@ -2038,14 +2038,14 @@ void Scumm::launch() {
// PALMOS : check if this value is correct with palm,
// old value 450000 doesn't work anymore (return _fntPtr = NULL in zak256, not tested with others)
- // 1500000 is too big and make ScummVM crashes : MemMove to NULL or immediate exit if try to allocate
+ // 2500000 is too big and make ScummVM crashes : MemMove to NULL or immediate exit if try to allocate
// memory with new operator
_maxHeapThreshold = 550000;